@@ -4,32 +4,32 @@
 #
 # -----------------------------------
 
-from .environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
+from .emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
 
-from materials.clay.montmorillonite_adsorption import MontmorilloniteAdsorption
-from materials.polymers.common_monomer_repeating_units import CommonMonomerRepeatingUnits
-
-from medicinal_chemistry.warheads.electrophillic_warheads_for_kinases import ElectrophilicWarheadsForKinases
-from medicinal_chemistry.warheads.common_warheads_covalent_inhibitors import CommonWarheadsCovalentInhibitors
-
-from medicinal_chemistry.rings.rings_in_drugs import RingsInDrugs
-from medicinal_chemistry.rings.iupac_blue_book_rings import IUPACBlueBookRings
-from medicinal_chemistry.rings.phase_2_hetereocyclic_rings import Phase2HetereoCyclicRings
-
-from medicinal_chemistry.scaffolds.privileged_scaffolds import PrivilegedScaffolds
-from medicinal_chemistry.scaffolds.iupac_blue_book_substituents import IUPACBlueBook
-from medicinal_chemistry.scaffolds.common_r_group_replacements import CommonRGroupReplacements
-
-from proteins.kinases.braf.common_groups_by_pocket import BRAFInhibitorsByPocket
-from proteins.kinases.scaffolds.privileged_scaffolds import PrivilegedKinaseInhibitorScaffolds
-
-from organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
-from organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
-
-from miscellaneous.vitamins import Vitamins
-from miscellaneous.open_smiles import OpenSmiles
-from miscellaneous.amino_acids import AminoAcids
-from miscellaneous.regex_patterns import CommonRegexPatterns
+# from materials.clay.montmorillonite_adsorption import MontmorilloniteAdsorption
+# from materials.polymers.common_monomer_repeating_units import CommonMonomerRepeatingUnits
+#
+# from medicinal_chemistry.warheads.electrophillic_warheads_for_kinases import ElectrophilicWarheadsForKinases
+# from medicinal_chemistry.warheads.common_warheads_covalent_inhibitors import CommonWarheadsCovalentInhibitors
+#
+# from medicinal_chemistry.rings.rings_in_drugs import RingsInDrugs
+# from medicinal_chemistry.rings.iupac_blue_book_rings import IUPACBlueBookRings
+# from medicinal_chemistry.rings.phase_2_hetereocyclic_rings import Phase2HetereoCyclicRings
+#
+# from medicinal_chemistry.scaffolds.privileged_scaffolds import PrivilegedScaffolds
+# from medicinal_chemistry.scaffolds.iupac_blue_book_substituents import IUPACBlueBook
+# from medicinal_chemistry.scaffolds.common_r_group_replacements import CommonRGroupReplacements
+#
+# from proteins.kinases.braf.common_groups_by_pocket import BRAFInhibitorsByPocket
+# from proteins.kinases.scaffolds.privileged_scaffolds import PrivilegedKinaseInhibitorScaffolds
+#
+# from organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
+# from organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
+#
+# from miscellaneous.vitamins import Vitamins
+# from miscellaneous.open_smiles import OpenSmiles
+# from miscellaneous.amino_acids import AminoAcids
+# from miscellaneous.regex_patterns import CommonRegexPatterns
 
 class GlobalChem(object):
 
